@@ -427,7 +427,9 @@ class FileBasedLockingTestCase(test_base.BaseTestCase):
     def test_interprocess_nonblocking_external_lock(self):
         """Check that we're not actually blocking between processes."""
 
-        nb_calls = multiprocessing.Value('i', 0)
+        # Use 'fork' context to avoid pickling issues with local functions
+        ctx = multiprocessing.get_context('fork')
+        nb_calls = ctx.Value('i', 0)
 
         @lockutils.synchronized('foo', blocking=False, external=True,
                                 lock_path=self.lock_dir)
@@ -439,7 +441,7 @@ class FileBasedLockingTestCase(test_base.BaseTestCase):
         def other(param):
             foo(param)
 
-        process = multiprocessing.Process(target=other, args=(nb_calls, ))
+        process = ctx.Process(target=other, args=(nb_calls, ))
         process.start()
         # Make sure the other process grabs the lock
         start = time.time()
@@ -447,7 +449,7 @@ class FileBasedLockingTestCase(test_base.BaseTestCase):
             if time.time() - start > 5:
                 self.fail('Timed out waiting for process to grab lock')
             time.sleep(0)
-        process1 = multiprocessing.Process(target=other, args=(nb_calls, ))
+        process1 = ctx.Process(target=other, args=(nb_calls, ))
         process1.start()
         process1.join()
         process.join()
